# CHANGELOG



## v1.0.0 (2024-04-27)

### :boom:

* :boom: add load_environment() func

Signed-off-by: rjdbcm &lt;rjdbcm@mail.umkc.edu&gt; ([`7cb9510`](https://github.com/OZI-Project/ozi_templates/commit/7cb951045f3855ab6a301ca52d536d96e4a3f0c0))

### :bug:

* :bug: fix release workflow outputs so publish is not skipped.

Signed-off-by: rjdbcm &lt;rjdbcm@outlook.com&gt; ([`2ce8dd0`](https://github.com/OZI-Project/ozi_templates/commit/2ce8dd0f24f52f9c497dd9dd57be6bdcd917b010))

* :bug: Fix publish workflow had ssh arguments still.

Signed-off-by: rjdbcm &lt;rjdbcm@outlook.com&gt; ([`77a8ede`](https://github.com/OZI-Project/ozi_templates/commit/77a8edef6915fc3324e0ac131500747a5a8d72f1))

* :bug: fix name normalization in project and template.

Without normalization we get duplicate dist_info.

Signed-off-by: rjdbcm &lt;rjdbcm@outlook.com&gt; ([`d40e46a`](https://github.com/OZI-Project/ozi_templates/commit/d40e46ae36927546cca0fe76baa2c870ccd6a2a7))

### :fire:

* :fire: delete template readme ([`33abd6c`](https://github.com/OZI-Project/ozi_templates/commit/33abd6c51075136fb8b40ba7c81e28a2b405f236))

### :pencil2:

* :pencil2: correct project name ([`9df80d8`](https://github.com/OZI-Project/ozi_templates/commit/9df80d8511050ab6596f5b10f8d7dc41be0c0924))

### Other

* Initial clone of templates

Signed-off-by: rjdbcm &lt;rjdbcm@mail.umkc.edu&gt; ([`a8370f9`](https://github.com/OZI-Project/ozi_templates/commit/a8370f94cf621f3035ce6ac956fe96a752b005d2))

* Bump github/codeql-action from 3.25.2 to 3.25.3

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.2 to 3.25.3.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/8f596b4ae3cb3c588a5c46780b86dd53fef16c52...d39d31e687223d841ef683f52467bd88e9b21c14)

---
updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`54566b3`](https://github.com/OZI-Project/ozi_templates/commit/54566b3f685b0a8757105c1ff8177eabdbe61d3e))

* Initial commit ([`6df66d3`](https://github.com/OZI-Project/ozi_templates/commit/6df66d3a74d25f7e06bb573249b8c065155b9358))
